==> haskell-cryptonite-conduit-0.2.2-534-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cryptonite-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cryptonite-conduit
version:              0.2.2
visibility:           public
id:                   cryptonite-conduit-0.2.2-6AXTVbtUiayEjVUMBb6fch
key:                  cryptonite-conduit-0.2.2-6AXTVbtUiayEjVUMBb6fch
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           vincent@snarc.org
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/haskell-crypto/cryptonite-conduit
synopsis:             cryptonite conduit
description:
    Conduit bridge for cryptonite

    For now only provide a conduit version for hash and hmac, but
    with contribution, this could provide cipher conduits too,
    and probably other things.

category:             Cryptography, Conduit
abi:                  5ab42c5a3a7a198a7d2a8f332405c752
exposed:              True
exposed-modules:
    Crypto.Cipher.ChaChaPoly1305.Conduit Crypto.Hash.Conduit
    Crypto.MAC.HMAC.Conduit Crypto.PubKey.ECIES.Conduit

import-dirs:          /usr/lib/ghc-9.0.2/site-local/cryptonite-conduit-0.2.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/cryptonite-conduit-0.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cryptonite-conduit
hs-libraries:         HScryptonite-conduit-0.2.2-6AXTVbtUiayEjVUMBb6fch
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    conduit-1.3.4.3-8itn5Qj41ZSLgRSjBhzqyF
    conduit-extra-1.3.6-LDUhnbBFGIILMmOycgbU6i
    cryptonite-0.30-1Rfjg2UxJ0tAQrwWuK0NlN exceptions-0.10.4
    memory-0.17.0-3DbDQrj54CLAPAnWUJBJ4b
    resourcet-1.2.6-3amKdWDZReE3TYUO4zdEYT transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-cryptonite-conduit/html/cryptonite-conduit.haddock

haddock-html:         /usr/share/doc/haskell-cryptonite-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cryptonite-conduit-0.2.2-583-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cryptonite-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cryptonite-conduit
version:              0.2.2
visibility:           public
id:                   cryptonite-conduit-0.2.2-HHQMjaeriEr3dI28FhNio6
key:                  cryptonite-conduit-0.2.2-HHQMjaeriEr3dI28FhNio6
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           vincent@snarc.org
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/haskell-crypto/cryptonite-conduit
synopsis:             cryptonite conduit
description:
    Conduit bridge for cryptonite

    For now only provide a conduit version for hash and hmac, but
    with contribution, this could provide cipher conduits too,
    and probably other things.

category:             Cryptography, Conduit
abi:                  cf196daa43275f4dc1e56dd6e342b913
exposed:              True
exposed-modules:
    Crypto.Cipher.ChaChaPoly1305.Conduit Crypto.Hash.Conduit
    Crypto.MAC.HMAC.Conduit Crypto.PubKey.ECIES.Conduit

import-dirs:          /usr/lib/ghc-9.0.2/site-local/cryptonite-conduit-0.2.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/cryptonite-conduit-0.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cryptonite-conduit
hs-libraries:         HScryptonite-conduit-0.2.2-HHQMjaeriEr3dI28FhNio6
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    conduit-1.3.5-Jq81tBeR2eG6Vm9Wfmg9Au
    conduit-extra-1.3.6-81BNaX6jVC8HfEWFG32czK
    cryptonite-0.30-A2WcUXrCplbraDFo3HWcX exceptions-0.10.4
    memory-0.17.0-Ba80JGdi30PBt5EgUiQ1Tu
    resourcet-1.2.6-AavQnD5kc82Iq3gAOb9Jer transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-cryptonite-conduit/html/cryptonite-conduit.haddock

haddock-html:         /usr/share/doc/haskell-cryptonite-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
